# getstanza

Python SDK for adding Stanza Systems fault tolerance to your Python 3 service.
Contains all core logic shared by all adapters, and provides functions that
allow usage of Stanza in a framework-independent manner.
